import type { AccountId } from "../models/AccountId";
import type { InitializeAccountRequest } from "../models/InitializeAccountRequest";
import type { InitializeAccountResponse } from "../models/InitializeAccountResponse";
import type { StartTrialRequest } from "../models/StartTrialRequest";
import type { UserId } from "../models/UserId";
export declare class AccountsService {
    /**
     * Creates a new account for the user and sets it as their primary account, if the user doesn't currently belong to
     * any accounts.
     * @param requestBody
     * @returns InitializeAccountResponse Success.
     * @throws ApiError
     */
    static initializeAccount(requestBody: InitializeAccountRequest): Promise<InitializeAccountResponse>;
    /**
     * List all the users who are members of an account.
     * @param accountId
     * @param userId
     * @returns void
     * @throws ApiError
     */
    static revokeMembership(accountId: AccountId, userId: UserId): Promise<void>;
    /**
     * Attempts to start a new free trial.
     *
     * Note 1: current business logic dictates the user can only call this in the first 14 days of creating their account,
     * and we don't allow calls to it after. However, in future we may allow the user to jump onto a free trial for
     * another plan after already being a paying user.
     *
     * Note 2: this method is not called during sign up (the free trial is started on account creation in that case).
     * Rather, this method is called only if the user switches trial via the dashboard in the first 14 days.
     * @param accountId
     * @param requestBody
     * @returns any Success.
     * @throws ApiError
     */
    static startFreeTrial(accountId: AccountId, requestBody: StartTrialRequest): Promise<any>;
}
