import type { AccountId } from "../models/AccountId";
import type { BeginUploadRequestV1 } from "../models/BeginUploadRequestV1";
import type { BeginUploadResponseV1 } from "../models/BeginUploadResponseV1";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { ContinuationToken } from "../models/ContinuationToken";
import type { DeleteFileBatch } from "../models/DeleteFileBatch";
import type { FileId } from "../models/FileId";
import type { FileSummaryExtended } from "../models/FileSummaryExtended";
import type { FileTagName } from "../models/FileTagName";
import type { FileTagPrefixSearch } from "../models/FileTagPrefixSearch";
import type { PageSize } from "../models/PageSize";
import type { Paginated_FileSummaryExtended_ } from "../models/Paginated_FileSummaryExtended_";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import type { UploadPartV1 } from "../models/UploadPartV1";
export declare class FilesV1Service {
    /**
     * Begins a new multipart file upload. Required API key type: 'secret_*' or 'public_*'.
     * @param requestBody File upload parameters.
     * @returns BeginUploadResponseV1 Success.
     * @throws ApiError
     */
    static beginMultipartUpload(requestBody: BeginUploadRequestV1): Promise<BeginUploadResponseV1>;
    /**
     * Deletes multiple files. Required API key type: 'secret_*' only.
     * @param requestBody
     * @returns void
     * @throws ApiError
     */
    static deleteFileBatch(requestBody: DeleteFileBatch): Promise<void>;
    /**
     * Lists the files for a given account. Required API key type: 'secret_*' only.
     * @param accountId
     * @param pageSize
     * @param fileTag
     * @param fileTagPrefixSearch
     * @param backwardToken
     * @param forwardToken
     * @returns Paginated_FileSummaryExtended_ Success.
     * @throws ApiError
     */
    static getFiles(accountId: AccountId, pageSize: PageSize, fileTag?: FileTagName, fileTagPrefixSearch?: FileTagPrefixSearch, backwardToken?: ContinuationToken, forwardToken?: ContinuationToken): Promise<Paginated_FileSummaryExtended_>;
    /**
     * Finalizes an upload part for an in-progress multipart upload. Required API key type: 'secret_*' or 'public_*'.
     * @param fileId
     * @param uploadPartIndex
     * @param requestBody
     * @returns void
     * @throws ApiError
     */
    static completeUploadPart(fileId: FileId, uploadPartIndex: UploadPartIndex, requestBody: CompleteUploadPartRequest): Promise<void>;
    /**
     * Gets a remaining upload part for an in-progress upload. Required API key type: 'secret_*' or 'public_*'.
     * @param fileId
     * @param uploadPartIndex
     * @returns UploadPartV1 Success.
     * @throws ApiError
     */
    static getUploadPart(fileId: FileId, uploadPartIndex: UploadPartIndex): Promise<UploadPartV1>;
    /**
     * Deletes a single file. Required API key type: 'secret_*' only.
     * @param fileId
     * @returns void
     * @throws ApiError
     */
    static deleteFile(fileId: FileId): Promise<void>;
    /**
     * Gets information about a specific file. Required API key type: 'secret_*' only.
     * @param fileId
     * @returns FileSummaryExtended Success.
     * @throws ApiError
     */
    static getFile(fileId: FileId): Promise<FileSummaryExtended>;
    /**
     * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete. Required API key type: 'secret_*' or 'public_*'.
     * @param fileId
     * @returns UploadPartList Success.
     * @throws ApiError
     */
    static getUploadParts(fileId: FileId): Promise<UploadPartList>;
}
