import type { AccountId } from "../models/AccountId";
import type { EmailAddress } from "../models/EmailAddress";
import type { Invitation } from "../models/Invitation";
import type { SendInvitation } from "../models/SendInvitation";
export declare class InvitationsService {
    /**
     * Sends an account invitation to an email address.
     * @param accountId
     * @param requestBody
     * @returns Invitation Success.
     * @throws ApiError
     */
    static sendInvitation(accountId: AccountId, requestBody: SendInvitation): Promise<Invitation>;
    /**
     * Accepts an account invitation.
     * @param accountId
     * @returns void
     * @throws ApiError
     */
    static acceptInvitation(accountId: AccountId): Promise<void>;
    /**
     * Revokes an account invitation to an email address.
     * @param accountId
     * @param email
     * @returns void
     * @throws ApiError
     */
    static revokeInvitation(accountId: AccountId, email: EmailAddress): Promise<void>;
}
