import type { AccountId } from "../models/AccountId";
import type { DeleteTransformationsBatch } from "../models/DeleteTransformationsBatch";
import type { TransformationDefinition } from "../models/TransformationDefinition";
import type { TransformationDefinitionData } from "../models/TransformationDefinitionData";
import type { TransformationDefinitionId } from "../models/TransformationDefinitionId";
export declare class TransformationsService {
    /**
     * Creates a new transformation for the account.
     * @param accountId
     * @param requestBody
     * @returns TransformationDefinition Success.
     * @throws ApiError
     */
    static createTransformation(accountId: AccountId, requestBody: TransformationDefinitionData): Promise<TransformationDefinition>;
    /**
     * Deletes multiple transformations from the account.
     * @param accountId
     * @param requestBody
     * @returns void
     * @throws ApiError
     */
    static deleteTransformationBatch(accountId: AccountId, requestBody: DeleteTransformationsBatch): Promise<void>;
    /**
     * Updates an existing transformation for the account.
     * @param accountId
     * @param transformationId
     * @param requestBody
     * @returns TransformationDefinition Success.
     * @throws ApiError
     */
    static updateTransformation(accountId: AccountId, transformationId: TransformationDefinitionId, requestBody: TransformationDefinitionData): Promise<TransformationDefinition>;
    /**
     * Deletes a transformation from the account.
     * @param accountId
     * @param transformationId
     * @returns void
     * @throws ApiError
     */
    static deleteTransformation(accountId: AccountId, transformationId: TransformationDefinitionId): Promise<void>;
}
