import type { AccountId } from "../models/AccountId";
import type { BeginUploadRequestV2 } from "../models/BeginUploadRequestV2";
import type { BeginUploadResponseV2 } from "../models/BeginUploadResponseV2";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { UploadId } from "../models/UploadId";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import type { UploadPartV2 } from "../models/UploadPartV2";
export declare class UploadsService {
    /**
     * Begins a new multipart file upload. Required API key type: 'secret_*' or 'public_*'.
     * @param accountId
     * @param requestBody File upload parameters.
     * @returns BeginUploadResponseV2 Success.
     * @throws ApiError
     */
    static beginMultipartUpload(accountId: AccountId, requestBody: BeginUploadRequestV2): Promise<BeginUploadResponseV2>;
    /**
     * Finalizes an upload part for an in-progress multipart upload. Required API key type: 'secret_*' or 'public_*'.
     * @param accountId
     * @param uploadId
     * @param uploadPartIndex
     * @param requestBody
     * @returns void
     * @throws ApiError
     */
    static completeUploadPart(accountId: AccountId, uploadId: UploadId, uploadPartIndex: UploadPartIndex, requestBody: CompleteUploadPartRequest): Promise<void>;
    /**
     * Gets a remaining upload part for an in-progress upload. Required API key type: 'secret_*' or 'public_*'.
     * @param accountId
     * @param uploadId
     * @param uploadPartIndex
     * @returns UploadPartV2 Success.
     * @throws ApiError
     */
    static getUploadPart(accountId: AccountId, uploadId: UploadId, uploadPartIndex: UploadPartIndex): Promise<UploadPartV2>;
    /**
     * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete. Required API key type: 'secret_*' or 'public_*'.
     * @param accountId
     * @param uploadId
     * @returns UploadPartList Success.
     * @throws ApiError
     */
    static getUploadParts(accountId: AccountId, uploadId: UploadId): Promise<UploadPartList>;
}
