/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { Jwt } from "../models/Jwt";
import type { SwitchPlan } from "../models/SwitchPlan";
import { request as __request } from "../core/request";

export class BillingService {
  /**
   * Generates the passthrough parameters to be used during checkout. Passthrough parameters are passed back to the
   * browser, which then passes them onto the billing gateway, which in turn passes them back to us via a webhook.
   * Therefore, the parameters need to be signed to prevent the user from modifying them in between.
   * @param accountId
   * @returns Jwt Success.
   * @throws ApiError
   */
  public static async generateSubscriptionPassthroughToken(accountId: AccountId): Promise<Jwt> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/billing/subscription_passthrough_tokens`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Called after the user's first checkout to indicate they got as far as completing the payment. Since this endpoint
   * can be called by malicious users without providing payment, the flag we store is never used to authenticate certain
   * actions that require payment details being set: it's merely used to provide an improved experience for
   * non-malicious users -- we use the flag to display a "we're creating your account" loading screen on the dashboard,
   * instead of redirecting the user to a payment details capture screen.
   * @param accountId
   * @returns void
   * @throws ApiError
   */
  public static async markPaymentDetailsAsSubmitted(accountId: AccountId): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/billing/payment_details_submitted`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes the user's subscription (i.e. payment details and tier) but not their account.
   * @param accountId
   * @returns void
   * @throws ApiError
   */
  public static async cancelSubscription(accountId: AccountId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/billing/subscription`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Switches the account onto a different plan.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async switchPlan(accountId: AccountId, requestBody: SwitchPlan): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/billing/plan`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
