/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { PublicKey } from "../models/PublicKey";
import type { PublicKeyData } from "../models/PublicKeyData";
import type { PublicKeyId } from "../models/PublicKeyId";
import type { RemovePublicKeyBatch } from "../models/RemovePublicKeyBatch";
import { request as __request } from "../core/request";

export class PublicKeysService {
  /**
   * Adds a public key to the account.
   * @param accountId
   * @param requestBody
   * @returns PublicKey Success.
   * @throws ApiError
   */
  public static async addPublicKey(accountId: AccountId, requestBody: PublicKeyData): Promise<PublicKey> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/public_keys`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Removes multiple public keys from the account.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async removePublicKeyBatch(accountId: AccountId, requestBody: RemovePublicKeyBatch): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/public_keys`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Removes a public key from the account.
   * @param accountId
   * @param publicKeyId
   * @returns void
   * @throws ApiError
   */
  public static async removePublicKey(accountId: AccountId, publicKeyId: PublicKeyId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/public_keys/${publicKeyId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
