/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { BeginUploadRequestV2 } from "../models/BeginUploadRequestV2";
import type { BeginUploadResponseV2 } from "../models/BeginUploadResponseV2";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { UploadId } from "../models/UploadId";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import type { UploadPartV2 } from "../models/UploadPartV2";
import { request as __request } from "../core/request";

export class UploadsService {
  /**
   * Begins a new multipart file upload. Required API key type: 'secret_*' or 'public_*'.
   * @param accountId
   * @param requestBody File upload parameters.
   * @returns BeginUploadResponseV2 Success.
   * @throws ApiError
   */
  public static async beginMultipartUpload(
    accountId: AccountId,
    requestBody: BeginUploadRequestV2
  ): Promise<BeginUploadResponseV2> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/uploads`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Finalizes an upload part for an in-progress multipart upload. Required API key type: 'secret_*' or 'public_*'.
   * @param accountId
   * @param uploadId
   * @param uploadPartIndex
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async completeUploadPart(
    accountId: AccountId,
    uploadId: UploadId,
    uploadPartIndex: UploadPartIndex,
    requestBody: CompleteUploadPartRequest
  ): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v1/accounts/${accountId}/uploads/${uploadId}/parts/${uploadPartIndex}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for an in-progress upload. Required API key type: 'secret_*' or 'public_*'.
   * @param accountId
   * @param uploadId
   * @param uploadPartIndex
   * @returns UploadPartV2 Success.
   * @throws ApiError
   */
  public static async getUploadPart(
    accountId: AccountId,
    uploadId: UploadId,
    uploadPartIndex: UploadPartIndex
  ): Promise<UploadPartV2> {
    const result = await __request({
      method: "GET",
      path: `/v1/accounts/${accountId}/uploads/${uploadId}/parts/${uploadPartIndex}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete. Required API key type: 'secret_*' or 'public_*'.
   * @param accountId
   * @param uploadId
   * @returns UploadPartList Success.
   * @throws ApiError
   */
  public static async getUploadParts(accountId: AccountId, uploadId: UploadId): Promise<UploadPartList> {
    const result = await __request({
      method: "GET",
      path: `/v1/accounts/${accountId}/uploads/${uploadId}/parts`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File not found.`
      }
    });
    return result.body;
  }
}
